@@ -2,19 +2,14 @@
 # Copyright 2009 (C) Pierre Duquesne <stackp@online.fr>
 # Licensed under the Revised BSD License.
 
-from edit import Sound
+import edit
+import clipboard
 from player import Player
 from event import Signal
 import effect
 import app
 import traceback
 
-class Clipboard(object):
-    # OMG! A Borg! (http://code.activestate.com/recipes/66531/)
-    __shared_state = {"clip": []}
-    def __init__(self):
-        self.__dict__ = self.__shared_state
-
 class Controller(object):
 
     def __init__(self, sound, player, graph, selection):
@@ -24,7 +19,7 @@ class Controller(object):
         self._sound = sound
         self.filename_changed = Signal()
         self.error = Signal()
-        self.clipboard = Clipboard()
+        self.clipboard = clipboard.Clipboard()
 
     def new(self):
         app.open_()
@@ -40,7 +35,7 @@ class Controller(object):
             try:
                 method(self, *args, **kwargs)
             except Exception, e:
-                print self.error("Error", str(e))
+                self.error("Error", str(e))
                 traceback.print_exc()
 
         wrapper.__name__ = method.__name__
@@ -57,7 +52,7 @@ class Controller(object):
     @_report_exception
     def load_sound(self, filename):
         self._player.pause()
-        self._sound = Sound(filename)
+        self._sound = edit.Sound(filename)
         self._graph.set_sound(self._sound)
         self._player.set_sound(self._sound)
         self._selection.unselect()
@@ -112,10 +107,20 @@ class Controller(object):
     @_report_exception
     def paste(self):
         start, end = self._selection.get()
-        # FIXME: error when number of channels doesn't match.
-        self._sound.paste(start, self.clipboard.clip)
+        self._sound.paste(start, end, self.clipboard.clip)
         self._selection.set(start, start + len(self.clipboard.clip))
 
+    @_report_exception
+    def mix(self):
+        start, end = self._selection.get()
+        self._sound.mix(start, end, self.clipboard.clip)
+        # FIXME: should be dealt with in Sound.
+        if start == end:
+            l = len(self.clipboard.clip)
+        else:
+            l = min(end - start, len(self.clipboard.clip))
+        self._selection.set(start, start + l)
+
     def trim(self):
         pass
 
@@ -137,27 +142,22 @@ class Controller(object):
     def zoom_fit(self):
         self._graph.zoom_fit()
 
-    def reverse(self):
-        self.effect('reverse')
+    def list_effects(self):
+        l = effect.effects.keys()
+        l.sort()
+        return l
 
-    def normalize(self):
-        self.effect('normalize')
+    def list_extensions(self):
+        return edit.list_extensions()
 
     def effect(self, name):
-        fx_class = effect.effects[name]
         if self._selection.selected():
             start, end = self._selection.get()
         else:
             start = 0
             end = len(self._sound.frames)
-        fx = fx_class(self._sound, (start, end))
-        self._sound.apply(fx)
-
-    def scroll_right(self):
-        pass
-
-    def scroll_left(self):
-        pass
+        fx = effect.effects[name]
+        fx(self._sound, start, end)
 
     def filename(self):
         return self._sound.filename
